@@ -435,7 +435,7 @@ def _getAttachments(msg_part):
 		if not filename:
 			continue
 	
-		attachments.append([filename, m.get_content_type(), m.get_payload(decode=True)])
+		attachments.append([filename.replace(" ","_"), m.get_content_type(), m.get_payload(decode=True)])
 
 	return attachments
 
